[![CircleCI](https://dl.circleci.com/status-badge/img/gh/hasii2011/OrthogonalDrawing/tree/master.svg?style=shield)](https://dl.circleci.com/status-badge/redirect/gh/hasii2011/OrthogonalDrawing/tree/master)
[![PyPI version](https://badge.fury.io/py/orthogonal.svg)](https://badge.fury.io/py/orthogonal)



# Orthogonal Drawing Algorithm

This project is a fork of [this project.](https://github.com/rawfh/orthogonal-drawing-algorithm)

